@@ -5,10 +5,13 @@ var namespacezypp_1_1exception__detail =
     [ "EnableIfNotException", "namespacezypp_1_1exception__detail.html#aae1e1ddcd4816058de69dcff0e818980", null ],
     [ "operator<<", "namespacezypp_1_1exception__detail.html#ad662ff05f3e85801bb274d44703f861d", null ],
     [ "do_ZYPP_RETHROW", "namespacezypp_1_1exception__detail.html#a3c3009a18eea05ffd388155d806d98ec", null ],
-    [ "do_ZYPP_FWD_EXCPT_PTR", "namespacezypp_1_1exception__detail.html#a790da97d995ad1dff7bc9882075ecb71", null ],
+    [ "do_ZYPP_FWD_EXCPT_PTR", "namespacezypp_1_1exception__detail.html#a3e7f4dd222c0e0a050bd9a1176b91e55", null ],
+    [ "do_ZYPP_CAUGHT", "namespacezypp_1_1exception__detail.html#a8a4ca588b6813111458e5fe0d99f11dc", null ],
     [ "do_ZYPP_THROW", "namespacezypp_1_1exception__detail.html#aea584d30f9864cc65be16501acbbb492", null ],
+    [ "do_ZYPP_THROW", "namespacezypp_1_1exception__detail.html#a4e2be04ad219c2ecd182dca1361280ff", null ],
     [ "do_ZYPP_CAUGHT", "namespacezypp_1_1exception__detail.html#a34414abcef67c9491c9454fa5feedb45", null ],
     [ "do_ZYPP_RETHROW", "namespacezypp_1_1exception__detail.html#a0110ed6a18676922f8d7ef452dc8792c", null ],
-    [ "do_ZYPP_EXCPT_PTR", "namespacezypp_1_1exception__detail.html#aefb5fc4c0396c4558f436919ad5707bb", null ],
+    [ "do_ZYPP_RETHROW", "namespacezypp_1_1exception__detail.html#a6f242d1766c359dc5f6dd72142198043", null ],
+    [ "do_ZYPP_EXCPT_PTR", "namespacezypp_1_1exception__detail.html#a9c792e7963773d2a2b29f60aa7f12466", null ],
     [ "operator<<", "structzypp_1_1exception__detail_1_1CodeLocation.html#a2628be4d6f911ccdee677671f7021095", null ]
 ];
\ No newline at end of file
