@@ -1,20 +1,43 @@
 var NAVTREEINDEX16 =
 {
-"classzypp_1_1Exception.html#adfa4b6972bcdc173455d7a01068e221a":[3,0,10,110,29],
-"classzypp_1_1Exception.html#adfa4b6972bcdc173455d7a01068e221a":[4,0,7,101,29],
-"classzypp_1_1Exception.html#ae2959336c7bf3ad65daa82a1b3f5db0d":[3,0,10,765],
-"classzypp_1_1Exception.html#ae2959336c7bf3ad65daa82a1b3f5db0d":[3,0,10,110,40],
-"classzypp_1_1Exception.html#ae2959336c7bf3ad65daa82a1b3f5db0d":[4,0,7,101,40],
+"classzypp_1_1Exception.html#aa2e831e022ace14a60cd613bc5e93038":[4,0,7,101,7],
+"classzypp_1_1Exception.html#aa414c262b7bd5c910a0000ccbfe08d04":[3,0,10,110,15],
+"classzypp_1_1Exception.html#aa414c262b7bd5c910a0000ccbfe08d04":[4,0,7,101,15],
+"classzypp_1_1Exception.html#aa70f13ecf9486a1425fab0e41e59b8fd":[3,0,10,110,22],
+"classzypp_1_1Exception.html#aa70f13ecf9486a1425fab0e41e59b8fd":[4,0,7,101,22],
+"classzypp_1_1Exception.html#ab49886233b7159bb8405d80cd374c791":[3,0,10,110,0],
+"classzypp_1_1Exception.html#ab49886233b7159bb8405d80cd374c791":[4,0,7,101,0],
+"classzypp_1_1Exception.html#ab823e1697eada045babc6de041645463":[3,0,10,110,26],
+"classzypp_1_1Exception.html#ab823e1697eada045babc6de041645463":[4,0,7,101,26],
+"classzypp_1_1Exception.html#abe37cc4bdc0355caeb63f97cffb4dbbe":[3,0,10,110,35],
+"classzypp_1_1Exception.html#abe37cc4bdc0355caeb63f97cffb4dbbe":[4,0,7,101,35],
+"classzypp_1_1Exception.html#ac26bc6ceaf90ec2fedffc03208d84da7":[3,0,10,110,28],
+"classzypp_1_1Exception.html#ac26bc6ceaf90ec2fedffc03208d84da7":[4,0,7,101,28],
+"classzypp_1_1Exception.html#aca14b2fdddbb77a623898688c0ce1d71":[3,0,10,110,25],
+"classzypp_1_1Exception.html#aca14b2fdddbb77a623898688c0ce1d71":[4,0,7,101,25],
+"classzypp_1_1Exception.html#ad49f65c08a73857674c8dd87eca936d1":[3,0,10,110,1],
+"classzypp_1_1Exception.html#ad49f65c08a73857674c8dd87eca936d1":[4,0,7,101,1],
+"classzypp_1_1Exception.html#ad914ee03c6d9a0b21d265f8f94a0acbf":[3,0,10,110,20],
+"classzypp_1_1Exception.html#ad914ee03c6d9a0b21d265f8f94a0acbf":[4,0,7,101,20],
+"classzypp_1_1Exception.html#adb6e3ba719e93c438ebbf72f62bde991":[3,0,10,110,10],
+"classzypp_1_1Exception.html#adb6e3ba719e93c438ebbf72f62bde991":[4,0,7,101,10],
+"classzypp_1_1Exception.html#adbed782d4b284c7bdb4554c2f2aca324":[3,0,10,110,13],
+"classzypp_1_1Exception.html#adbed782d4b284c7bdb4554c2f2aca324":[4,0,7,101,13],
+"classzypp_1_1Exception.html#adfa4b6972bcdc173455d7a01068e221a":[3,0,10,110,30],
+"classzypp_1_1Exception.html#adfa4b6972bcdc173455d7a01068e221a":[4,0,7,101,30],
+"classzypp_1_1Exception.html#ae2959336c7bf3ad65daa82a1b3f5db0d":[3,0,10,766],
+"classzypp_1_1Exception.html#ae2959336c7bf3ad65daa82a1b3f5db0d":[3,0,10,110,41],
+"classzypp_1_1Exception.html#ae2959336c7bf3ad65daa82a1b3f5db0d":[4,0,7,101,41],
 "classzypp_1_1Exception.html#ae4e984428c1a3b9681ee7c2080731337":[3,0,10,110,12],
 "classzypp_1_1Exception.html#ae4e984428c1a3b9681ee7c2080731337":[4,0,7,101,12],
-"classzypp_1_1Exception.html#ae7b61412be1ceed53f3537bd3eadeb43":[3,0,10,110,20],
-"classzypp_1_1Exception.html#ae7b61412be1ceed53f3537bd3eadeb43":[4,0,7,101,20],
-"classzypp_1_1Exception.html#af20cf4667dbdb71bccb1c04cd4b4c032":[3,0,10,110,28],
-"classzypp_1_1Exception.html#af20cf4667dbdb71bccb1c04cd4b4c032":[4,0,7,101,28],
-"classzypp_1_1Exception.html#af6a5a1a9527e907e19bd94d61e0dc2be":[3,0,10,110,17],
-"classzypp_1_1Exception.html#af6a5a1a9527e907e19bd94d61e0dc2be":[4,0,7,101,17],
-"classzypp_1_1Exception.html#aff85cc52e41494f5cc63b6003461e98e":[3,0,10,110,23],
-"classzypp_1_1Exception.html#aff85cc52e41494f5cc63b6003461e98e":[4,0,7,101,23],
+"classzypp_1_1Exception.html#ae7b61412be1ceed53f3537bd3eadeb43":[3,0,10,110,21],
+"classzypp_1_1Exception.html#ae7b61412be1ceed53f3537bd3eadeb43":[4,0,7,101,21],
+"classzypp_1_1Exception.html#af20cf4667dbdb71bccb1c04cd4b4c032":[3,0,10,110,29],
+"classzypp_1_1Exception.html#af20cf4667dbdb71bccb1c04cd4b4c032":[4,0,7,101,29],
+"classzypp_1_1Exception.html#af6a5a1a9527e907e19bd94d61e0dc2be":[3,0,10,110,18],
+"classzypp_1_1Exception.html#af6a5a1a9527e907e19bd94d61e0dc2be":[4,0,7,101,18],
+"classzypp_1_1Exception.html#aff85cc52e41494f5cc63b6003461e98e":[3,0,10,110,24],
+"classzypp_1_1Exception.html#aff85cc52e41494f5cc63b6003461e98e":[4,0,7,101,24],
 "classzypp_1_1ExternalProgram.html":[3,0,10,111],
 "classzypp_1_1ExternalProgram.html":[4,0,7,102],
 "classzypp_1_1ExternalProgram.html#a040f7a07960008292ab4352fe9222502":[3,0,10,111,4],
@@ -111,7 +134,7 @@ var NAVTREEINDEX16 =
 "classzypp_1_1Fetcher.html#a28b775d82981d5bd19bb91b18f502bae":[4,0,7,105,8],
 "classzypp_1_1Fetcher.html#a2a47459ad8aeb3228a88d8c2e1959e10":[3,0,10,114,7],
 "classzypp_1_1Fetcher.html#a2a47459ad8aeb3228a88d8c2e1959e10":[4,0,7,105,7],
-"classzypp_1_1Fetcher.html#a2b6e2ecbf365b3808310e612e470b335":[3,0,10,681],
+"classzypp_1_1Fetcher.html#a2b6e2ecbf365b3808310e612e470b335":[3,0,10,682],
 "classzypp_1_1Fetcher.html#a2b6e2ecbf365b3808310e612e470b335":[3,0,10,114,20],
 "classzypp_1_1Fetcher.html#a2b6e2ecbf365b3808310e612e470b335":[3,0,10,114,22],
 "classzypp_1_1Fetcher.html#a2b6e2ecbf365b3808310e612e470b335":[4,0,7,105,20],
@@ -226,28 +249,5 @@ var NAVTREEINDEX16 =
 "classzypp_1_1Fetcher_1_1Impl.html#ac4a7c65497bb9085f34412f3ae8c83b0":[4,0,7,105,0,19],
 "classzypp_1_1Fetcher_1_1Impl.html#ad5c0fb5cb1ff99231007f8d2e159b468":[3,0,10,114,0,14],
 "classzypp_1_1Fetcher_1_1Impl.html#ad5c0fb5cb1ff99231007f8d2e159b468":[4,0,7,105,0,14],
-"classzypp_1_1Fetcher_1_1Impl.html#ad6f7c2785383eba1b3c3629c15779968":[3,0,10,114,0,17],
-"classzypp_1_1Fetcher_1_1Impl.html#ad6f7c2785383eba1b3c3629c15779968":[4,0,7,105,0,17],
-"classzypp_1_1Fetcher_1_1Impl.html#ae15ba079e7f7067c9dabfa93fc8b7737":[3,0,10,114,0,7],
-"classzypp_1_1Fetcher_1_1Impl.html#ae15ba079e7f7067c9dabfa93fc8b7737":[4,0,7,105,0,7],
-"classzypp_1_1Fetcher_1_1Impl.html#ae426ba6b8296844f55b80adcc8a9ba1f":[3,0,10,114,0,41],
-"classzypp_1_1Fetcher_1_1Impl.html#ae426ba6b8296844f55b80adcc8a9ba1f":[4,0,7,105,0,41],
-"classzypp_1_1Fetcher_1_1Impl.html#ae808fe079fe1681c6375b97c21dbe98d":[3,0,10,114,0,1],
-"classzypp_1_1Fetcher_1_1Impl.html#ae808fe079fe1681c6375b97c21dbe98d":[4,0,7,105,0,1],
-"classzypp_1_1Fetcher_1_1Impl.html#af53cdcbc308ef43fcf55263e7ca6ace8":[3,0,10,114,0,4],
-"classzypp_1_1Fetcher_1_1Impl.html#af53cdcbc308ef43fcf55263e7ca6ace8":[4,0,7,105,0,4],
-"classzypp_1_1Fetcher_1_1Impl.html#af912639bc084feade4344570b807da3c":[3,0,10,114,0,16],
-"classzypp_1_1Fetcher_1_1Impl.html#af912639bc084feade4344570b807da3c":[4,0,7,105,0,16],
-"classzypp_1_1FileCheckException.html":[3,0,10,117],
-"classzypp_1_1FileCheckException.html":[4,0,7,108],
-"classzypp_1_1FileCheckException.html#a2f2e2aa0976c761a2c51ae92dc890dd3":[3,0,10,117,0],
-"classzypp_1_1FileCheckException.html#a2f2e2aa0976c761a2c51ae92dc890dd3":[4,0,7,108,0],
-"classzypp_1_1HACK_1_1Callback.html":[3,0,10,15,0],
-"classzypp_1_1HACK_1_1Callback.html":[4,0,7,13,0],
-"classzypp_1_1HistoryLog.html":[3,0,10,122],
-"classzypp_1_1HistoryLog.html":[4,0,7,113],
-"classzypp_1_1HistoryLog.html#a0379efdcd7ca2e5c1a25bb34bb0c80b9":[3,0,10,122,2],
-"classzypp_1_1HistoryLog.html#a0379efdcd7ca2e5c1a25bb34bb0c80b9":[4,0,7,113,2],
-"classzypp_1_1HistoryLog.html#a1cdcac9275433cee68cde5ad15a4c4db":[3,0,10,122,0],
-"classzypp_1_1HistoryLog.html#a1cdcac9275433cee68cde5ad15a4c4db":[4,0,7,113,0]
+"classzypp_1_1Fetcher_1_1Impl.html#ad6f7c2785383eba1b3c3629c15779968":[3,0,10,114,0,17]
 };
